##
# Detectors
In FDTDX, detectors can be used to perform measurements within a simulation. In conjunction with the Logger, these detectors can also automatically produce plots or even videos.

::: fdtdx.objects.detectors.EnergyDetector

::: fdtdx.objects.detectors.PoyntingFluxDetector

::: fdtdx.objects.detectors.PhasorDetector

::: fdtdx.objects.detectors.DiffractiveDetector
